﻿using System;
using System.Drawing;
using System.Windows.Forms;

using MindFusion.Mapping;


namespace ColorCoding
{
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();
		}

		private void MainForm_Load(object sender, EventArgs e)
		{
			// load the map file and dbf database
			var map = mapView.BaseMap = Map.FromFile(
				"ne_50m_admin_0_countries.shp", true, "NAME");
			var db = map.Database;
			var layer = mapView.Layers[0];

			// specify threshold values that trigger more saturated colors
			var m = 1000000;
			var populationThreshold = new[]
			{
				0, 1*m, 5*m, 10*m, 50*m, 100*m, 1000*m
			};

			int numColors = populationThreshold.Length;

			// set the layer palette with a color for each threshold value
			layer.FillColors = new Color[numColors];
			layer.FillColors[0] = Color.WhiteSmoke;
			for (int i = 1; i < numColors; i++)
			{
				layer.FillColors[i] = Color.FromArgb(
					255,
					255 - 255 / (numColors - i),
					255 - 255 / (numColors - i));
			}

			// for each database record, read population field and set color
			for (int i = 0; i < db.Rows.Count; i++)
			{
				var countryShape = map.Shapes[i];
				var population = float.Parse(db.Rows[i]["POP_EST"]);

				for (int c = numColors - 1; c >= 0; c--)
				{
					if (population > populationThreshold[c])
					{
						countryShape.Color = c;
						break;
					}
				}
			}
		}
	}
}